# This file handles configuration of a pbuilder chroot for a Debian package
# build system.  The public interface for this file is the define specified at
# the very top.  This sets up a chroot and build environment for a specified
# distribution.
#
# This define only partly supports ensure to the extent of not doing any work
# if ensure isn't set to present.  It doesn't, however, support removing
# configuration on ensure => absent.

define su_debuild::chroot(
  $ensure,
  $distribution = undef,
  $debian_type  = undef,
) {
  if !($ensure in [ 'present', 'absent' ]) {
    fail("ensure must be present or absent, not $ensure")
  }

  $distribution_real = $distribution ? {
    undef   => $name,
    default => $distribution
  }

  if ($ensure == 'present') {
    $path    = "/var/cache/pbuilder/base-${name}.cow"
    $config  = "/etc/pbuilder/${name}-no-stanford-keyring"
    $options = "--distribution ${distribution_real} --configfile ${config}"

    # We need two versions of each pbuilder configuration file: one
    # with stanford-keyring and one without.
    su_debuild::pbuilder_conf { "${distribution_real}-with-stanford-keyring":
      distribution             => $distribution_real,
      debian_type              => $debian_type,
      include_stanford_keyring => true,
    }
    su_debuild::pbuilder_conf { "${distribution_real}-without-stanford-keyring":
      distribution             => $distribution_real,
      debian_type              => $debian_type,
      include_stanford_keyring => false,
    }

    # If this is an Ubuntu distribution, link the distribution name to
    # "gutsy".
    if ($distribution_real =~ /quantal|raring|trusty|xenial|bionic/) {
      file { "/usr/share/debootstrap/scripts/${distribution_real}":
        ensure => 'link',
        target => '/usr/share/debootstrap/scripts/gutsy',
      }
    }

    # There is a chicken-and-egg problem in getting the stanford
    # repository's public key installed.  We do this as follows:
    #
    #  0. Install the chroot WITHOUT the stanford-keyring.
    #  1. Copy the correct distribution's sources.list file to /etc/apt.
    #  2. Do an "apt-get update". This will generate some complaints
    #     due to the stanford repository not having a public key.
    #  3. Install stanford-keyring which contains the stanford repository
    #     public key. This has to be installed in "untrusted" mode since
    #     it contains the key needed for trust.

    # 0. Create the chroot WITHOUT the stanford-keyring.
    exec { "cowbuilder --create ${name}":
      command => "cowbuilder --create --basepath ${path} ${options}",
      creates => $path,
      require => [ Package['cowdancer'],
        File['/etc/pbuilderrc'],
        File["/etc/pbuilder/${name}-no-stanford-keyring"] ],
    }

    # 1. Copy the stanford keyring file from the host computer.
    file { "${path}/etc/apt/trusted.gpg.d/stanford-keyring.gpg":
        ensure  => present,
        source  => '/usr/share/keyrings/stanford-keyring.gpg',
        require => Exec["cowbuilder --create ${name}"];
    }

    # 2. Copy the correct sources.list.
    file { "$path/etc/apt/sources.list":
      source  => "puppet:///modules/su_debuild/etc/apt/sources.list.${name}",
      require => File["${path}/etc/apt/trusted.gpg.d/stanford-keyring.gpg"],
    }

    # 3. Install stanford-keyring. Be sure to run "apt-get update" first.
    # Only run if /usr/share/keyrings/stanford-keyring.gpg (in chroot)
    # does _not_ already exist.
    exec { "install stanford-keyring in $path chroot":
      path    => '/usr/sbin:/usr/bin:/bin:/sbin',
      command => "chroot $path apt-get update; chroot $path apt-get install stanford-keyring",
      creates => "$path/usr/share/keyrings/stanford-keyring.gpg",
      require => [
        File["$path/etc/apt/sources.list"],
        File["${path}/etc/apt/trusted.gpg.d/stanford-keyring.gpg"],
      ]
    }

  } else {
    # ABSENT
    notify { "absent not done yet": }
  }

}

